@@ -52,7 +52,7 @@ Example of GitHub Actions workflow:
         - uses: actions/setup-python@v5
         - name: Install dependencies
           run: |
-            pip install stouputils m2r2 myst_parser sphinx_breeze_theme
+            pip install stouputils[docs,data_science]
         - name: Build version docs
           run: |
             python scripts/create_docs.py ${GITHUB_REF#refs/tags/v}
